:mod:`lck.concurrency.synchronization`
======================================


.. automodule:: lck.concurrency.synchronization

.. note::

  Instead of importing the whole structure, a recommended shortcut is available.
  Use ``from lck.concurrency import synchronized``.

Functions
----------

.. autofunction:: synchronized
